@@ -27,6 +27,18 @@ void force(char *who, char *where)
 	
     log(log_default, "Calling %s at %s", who, where);
 
+    if (get_line_to_use(dest))          /* determine the ttyline to be used */
+    {
+        printf
+        (
+            "\n"
+            "No line available to callback %s at %s.\n"
+            , who
+            , where
+        );
+        return;
+    }
+
     assign_filenames(get_active_tty());
 
     setcallback(uid, dest);		/* set the callbackfile */
