@@ -19,7 +19,7 @@
 #define NTRIES              3       
      
 /* What is the name of the modem-process (without the ttySx-suffix) */
-#define MODEMPROCESS        "/sbin/modem"
+#define MODEMPROCESS        "/usr/local/sbin/modem"
 
 /* What is the name of the receiver of mail ? (I don't like this, but */
 /* guess it's available)                                              */
@@ -28,8 +28,9 @@
 /* What is the name of the login-program */
 #define LOGIN_PROGRAM       "/bin/login" 
 
-/* What is the name of the mgetty-config file for callback ? */
-#define MGETTY_PATH         "/usr/local/etc/mgetty+sendfax/mgetty.config"
+/* What is the name of the mgetty-config file for callback ?    */
+/* (this one is according the Debian configuration of mgetty)   */
+#define MGETTY_PATH         "/etc/mgetty/mgetty.config"
 
 /* What is the name of the base-path for the callback-configuration files ? */
 /* Note: the default MUST have a trailing /                                 */
@@ -63,23 +64,23 @@
 */
 
 /* Where are the callback-setup files found ? */
-#define FIRSTSETUP	   "/etc/callback.setup"
-#define SECONDSETUP	   "/usr/etc/callback.setup"
-#define THIRDSETUP	   "/usr/local/etc/callback.setup"
+#define FIRSTSETUP         "/etc/callback.setup"
+#define SECONDSETUP        "/usr/etc/callback.setup"
+#define THIRDSETUP         "/usr/local/etc/callback.setup"
 
 /* In lib/process/killinit.c:
    ~~~~~~~~~~~~~~~~~~~~~~~~~~
 */
 
 /* Process-id of init. Should be 1. */
-#define PID_INIT		1
+#define PID_INIT                1
 
 /* In lib/process/modemrespawn.c:
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */
 
 /*  Program to determine the running processes. */
-#define PSCMD			"ps -ax"
+#define PSCMD                   "ps -ax"
 
 /*  In policy.h: 
     ~~~~~~~~~~~~ 
