@@ -27,10 +27,11 @@ void update_cbstate(char *line);
 void enable_state();
 void make_configfile();
 void setcallback(int uid, int dest);
-void load(THE_FILE_ENUM_ the_source);
+void load(THE_FILE_ENUM_ the_source, int rm_disablefile);
 char *getfile(THE_FILE_ENUM_ ftype);
 void active_files();
 void states();
-void assign_filenames(char *line);
+void assign_filenames(char *line);  
+void unlink_files();
 
 #endif  _dbase_H_
