@@ -3,8 +3,7 @@
 
 void enable_state()
 {
-    unlink(filename[the_statefile]);
-    unlink(filename[the_disablefile]);
+    unlink_files();
     copyfile(filename[the_enablefile], filename[the_activefile]);
     make_configfile();
 }
