@@ -17,8 +17,10 @@ void update_cbstate(char *line)
         break;                         
                
         case -1:    /* absent file */
-            log(log_on, "Callback standby on line %s",
-	                 line);
+            if (!access(filename[the_disablefile], R_OK))
+                log(log_on, "Incoming calls on line %s disabled", line);
+            else
+                log(log_on, "Standing by for incoming calls on line %s", line);
         break;
 
         case 0:     /* states exhausted */
