@@ -16,6 +16,7 @@ unsigned get_dnameindex(unsigned destindex);
 unsigned get_dgroupindex(unsigned destindex);
 unsigned get_ndestinations();
 char *get_phone();
+int get_line_to_use(int dest);  
 char *get_filename();
 char *getbuf(char *buf, unsigned buflen);
 
@@ -25,6 +26,7 @@ void set_dname(char *dname);
 void set_cbmode(MODE_ mode);
 void set_phone(char *phone);
 void set_file(char *filename);
+void set_line(char *line);          /* line to use for callback */
 void tag_dnames();
 void ask_extra_number(unsigned uid, unsigned dest);
 
