@@ -10,15 +10,15 @@ void logv(char *fmt, va_list args)
 
     if 
     (
-        (logfile = fopen (log_filename, "a")) // logfile opened ok
+        (logfile = fopen (log_filename, "a")) /* logfile opened ok */
         ||
-        (logfile = fopen (panic_filename, "a")) // panicfile opened ok
+        (logfile = fopen (panic_filename, "a")) /* panicfile opened ok */
     )
     {
         time (&ltime); 
         fprintf
 	(
-	    logfile, "%s %s V %s ", ctime (&ltime),
+	    logfile, "%s %s V %s: ", ctime (&ltime),
 	    getprogname(), version
 	);
         vfprintf (logfile, fmt, args);
