@@ -6,7 +6,7 @@ void killinit()
 {
     activate_ttylines();		/* kill them all */
 
-    load(the_enablefile);		/* reload the enable files */
+    load(the_enablefile, 1);		/* reload the enable files */
 
     make_configfile();                  /* make final configuration file */
 
