@@ -28,6 +28,17 @@ void first_login(char *username)
 	default:			/* to catch the phonemode */
     }
 
+    if (get_line_to_use(dest))          /* determine the line to be used */
+    {
+        printf
+        (
+            "\n"
+            "No line available for callback.\n"
+            "Please break the connection and try again later.\n"
+        );
+        return;
+    }
+
     setcallback(uid, dest);              /* set callback mode */
 
     printf
